#' Permutation importance based on conditional random forest importance
#'
#' This function calculates permutation importance based on conditional random forests. Predictor variables must be continuous or dichotomous. Multi-category factors are not supported.
#' @param y The outcome vector.
#' @param x Matrix of predictors.
#' @param ntree Number of trees for the random forest run. The default value is \code{50}.
#' @param scale Should the permutation importances be ``scaled''? The default is \code{FALSE}.
#' @export

CRF_vimp <- function(x, y,
                     scale = FALSE,
                     ntree = 50,
                     mtry = if (!is.null(y) && !is.factor(y))
                       max(floor(ncol(x)/3), 1) else floor(sqrt(ncol(x)))) {
  if(is.null(x) | length(x) == 0) return(NULL)
  n <- dim(x)[1]
  p <- dim(x)[2]
  if(p == 1) {
    crf <- RF_vimp(x = x, y = y, ntree = ntree)
    names(crf) <- names(x); return(crf) }
  dat_whole <- data.frame(cbind(x,"Y" = y))
  RFs <- replicate(n = ntree, expr = randomForest::randomForest(x = x, y = y, keep.forest = TRUE, ntree = 1), simplify = FALSE)
  imps <- oaiC(rf_list = RFs, dat = dat_whole)
  rownames(imps) <- names(x)
  if(scale) return(imps[,2])
  if(!scale) return(imps[,1])
}

