#' Variable selection via conditional independence testing with Gaussian Bayesian networks.
#'
#' This function implements de Luna, Waernbaum, & Richardson's (2011) "XY" algorithm using mutual information with Bayesian networks as implemented in package \pkg{bnlearn} for testing conditional independence.
#' @param X Matrix of predictors.
#' @param Y The outcome variable.
#' @param T The treatment (exposure) variable. Must be dichotomous 0/1.
#' @param alpha Type I error rate. The default is \code{.05}.
#' @param method See documentation for \pkg{bnlearn}. Default is \code{mmpc}.
#' @keywords Variable Selection for Causal Inference Using Bayesian Networks
#' @export

gbn_xy <- function(X, Y, T, alpha = .05, method = "mmpc") {
  Xsubs0 <- X[T == 0,]; Xsubs1 <- X[T == 1,]
  Y0 <- Y[T == 0]; Y1 <- Y[T == 1]
  X0 <- bnlearn::learn.nbr(x = cbind(Xsubs0, Y0), node = "Y0", method = method, alpha = alpha)
  X1 <- bnlearn::learn.nbr(x = cbind(Xsubs1, Y1), node = "Y1", method = method, alpha = alpha)
  XY <- sort(union(X0, X1))
  XY
}

