# Hidden functions for conditional importance

formula_func <- function(var_names, index) {
  fmla <- paste0(var_names[index], " ~ ", paste0(var_names[-index], collapse = " + "))
  fmla }

subs_func <- function(vec, oob_ind) { vec[which(oob_ind == 1)] }
seqs_tab <- function(tab) { lapply(X = tab, FUN = seq, from = 1)}
seqs_sample <- function(sqs) { lapply(X = sqs, FUN = sample, replace = FALSE)}

mspe_func <- function(orig, newd) { mean((orig - newd)^2) }

perm_func_cond_help <- function(perm, ind, dat, nm, tree_fits_oob) {
  dat[which(tree_fits_oob[[ind]] == nm), ind] <- dat[which(tree_fits_oob[[ind]] == nm), ind][perm]
  dat }

perm_func_cond <- function(perm_lst, index, dat, tree_fits_oob) {
  nms <- names(perm_lst)
  for(i in 1:length(nms)) {
    dat <- perm_func_cond_help(perm = perm_lst[[i]],
                               ind = index,
                               dat = dat,
                               nm = nms[i],
                               tree_fits_oob = tree_fits_oob) }
  dat }

rfpred <- function(rfobj, newdat) {
  preds <- randomForest:::predict.randomForest(
    object = rfobj,
    newdata = newdat)
  preds }

tree_func <- function(fmla, dattta) {
  dattta <<- dattta
  if(!is.data.frame(dattta)) dattta <<- as.data.frame(dattta)
  nn <- dim(dattta)[1]
  treee <- rpart::rpart(formula = fmla, data = dattta,
                        control = rpart::rpart.control(maxsurrogate = 0,
                                                       xval = 0, cp = .01,
                                                       minbucket = max(10, round(nn*.05)),
                                                       maxcompete = 0))
  if(is.null(treee)) {nodes <- rep(1, times = dim(dattta)[1])} else {
    nodes <- predict(partykit::as.party(treee), type = "node") }
  nodes }

stiC <- function(rfobj, dat) { # single tree importance - conditional; outcome name in dat is assumed to be "Y"
  roc <- FALSE
  if(rfobj$type == "classification") {if(length(table(outcome)) == 2) {assign("roc", TRUE)} else {
    stop("Multicategory outcome not supported")}}
  pred_names <- names(dat[,-which(names(dat) == "Y")])
  oobs <- rfobj$oob.times
  noobs <- sum(oobs)
  dat_oobs <- dat[which(oobs == 1), -which(names(dat) == "Y")]
  oobs_otcms <- dat[which(oobs == 1), "Y"]
  npreds <- dim(dat)[2] - 1
  preds <- rfpred(rfobj = rfobj, newdat = dat_oobs)
  if(roc) {ERR <- roc_func(orig = oobs_otcms, newd = preds)} else {
    ERR <- mspe_func(orig = oobs_otcms, newd = preds)}
  forms <- lapply(X = 1:length(pred_names), FUN = formula_func, var_names = pred_names)
  # Get group classification by terminal node membership
  tree_fits <- lapply(X = forms, FUN = tree_func, dattta = dat[, pred_names])
  # Subset oob
  tree_fits_oob <- lapply(X = tree_fits, FUN = subs_func, oob_ind = oobs)
  # Tables of terminal node frequencies
  tabs <- lapply(X = tree_fits_oob, FUN = table)
  seqs <- lapply(X = tabs, FUN = seqs_tab)
  perms <- lapply(X = seqs, FUN = seqs_sample)

  perm_dat <- dat_oobs
  lngth <- dim(perm_dat)[2]
  for(j in 1:lngth) {
    perm_dat <- perm_func_cond(perm_lst = perms[[j]],
                               index = j,
                               dat = perm_dat,
                               tree_fits_oob = tree_fits_oob) }
  perm_dat_list <- vector(length = lngth, mode = "list")
  for(i in 1:lngth) {
    perm_dat_list[[i]] <- dat_oobs
    perm_dat_list[[i]][,i] <- perm_dat[,i] }

  imp_preds <- lapply(X = perm_dat_list, FUN = rfpred, rfobj = rfobj)
  if(roc) {ERRs <- sapply(X = imp_preds, FUN = roc_func, orig = oobs_otcms)} else {
    ERRs <- sapply(X = imp_preds, FUN = mspe_func, orig = oobs_otcms) }
  if(roc) {imp_raw <- ERR - ERRs} else {
    imp_raw <- ERRs - ERR }
  imp_raw
}

oaiC <- function(rf_list, dat) { # overall importance - Conditional; outcome name must be "Y"
  imps <- lapply(X = rf_list, FUN = stiC, dat = dat)
  imps <- matrix(unlist(imps), length(imps), length(imps[[1]]), byrow = TRUE)
  raw_imps <- apply(imps, 2, mean)
  scaled_imps <- apply(imps, 2, mean)/(apply(imps, 2, sd) / sqrt(dim(imps)[1]))
  out <- cbind(raw_imps, scaled_imps)
  colnames(out) <- c("raw", "scaled")
  out }

# tree_func <- function(fmla, dattta) {
#   dattta <<- dattta
#   if(!is.data.frame(dattta)) dattta <<- as.data.frame(dattta)
#   treee <- rpart::rpart(formula = fmla, data = dattta,
#                         control = rpart::rpart.control(maxsurrogate = 0))
#   ind <- min(which(treee$cptable[,"xerror"] == min(treee$cptable[,"xerror"])))
#   cpp <- treee$cptable[ind,"CP"]
#   prnd_tree <- tryCatch(rpart::prune(tree = treee, cp = cpp),
#                         error = function(e) NULL)
#   if(is.null(prnd_tree)) {nodes <- rep(1, times = dim(dattta)[1])} else {
#     nodes <- predict(partykit::as.party(prnd_tree), type = "node") }
#   nodes }