% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RFXY_cond.R
\name{RFXY_cond}
\alias{RFXY_cond}
\title{Implementation of de Luna, Waernbaum, & Richardson's (2011) "XY" algorithm. Calls \code{RFVS_perm_cond} for variable selection.}
\usage{
RFXY_cond(X, Y, T, perms = 10, ntree = 50, pctl = 0.95,
  scale = FALSE, permcores = 1)
}
\arguments{
\item{X}{Matrix of predictors.}

\item{Y}{The outcome variable.}

\item{T}{The treatment (exposure) variable. Must be dichotomous 0/1.}

\item{perms}{The number of permutation replications used to create a null distribtuion for importance values. The default value is \code{10}.}

\item{ntree}{The number of trees for the random forest run. The default value is \code{50}.}

\item{pctl}{The percentile of the null permutation distribution of importance used as a threshold for variable selection. The default is \code{pctl = .95}.}

\item{scale}{Should the permutation importances be ``scaled''? The default value is \code{FALSE}.}

\item{permcores}{Number of processor cores to use for parallel computing with package \pkg{parallel} for running the \code{perms} permutations. The default is no parallel computing (i.e., \code{permcores = 1}). Note that pkg{parallel} is not compatible with Windows versions of R. Specifically, if running Windows, \code{mclapply} will revert to \code{lapply}, so the function will still run, but with no parallelization.}
}
\description{
This function implements de Luna, Waernbaum, & Richardson's (2011) "XY" algorithm using random forests with conditional variable importance under permutation for testing conditional independence.
}
\keyword{Forest}
\keyword{Importance}
\keyword{Permutation}
\keyword{Random}
\keyword{Selection}
\keyword{Variable}
