% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RFXY_cond_wrap.R
\name{RFXY_cond_wrap}
\alias{RFXY_cond_wrap}
\title{Wrapper for \code{RFXY_cond}.}
\usage{
RFXY_cond_wrap(X, Y, T, perms = 20, ntree = 200, permsCond = 10,
  ntreeCond = 50, pctl = 0.95, scale = FALSE, sidak = TRUE,
  iterate = FALSE, permcores = 1)
}
\arguments{
\item{X}{Matrix of predictors.}

\item{Y}{The outcome variable. Continuous outcome and dichotomous factor outcome are permitted.}

\item{T}{The treatment (exposure) variable. Must be dichotomous 0/1.}

\item{perms}{The number of permutation replications used to create a null distribution for preprocessing with traditional RF importance values. The default value is \code{20}.}

\item{ntree}{The number of trees for the random forest runs for traditional RF importance values. The default value is \code{200}.}

\item{permsCond}{The number of permutation replications used to create a null distribution for preprocessing with conditional RF importance values. The default value is \code{10}.}

\item{ntreeCond}{The number of trees for the random forest runs for conditional RF importance values. The default value is \code{50}.}

\item{pctl}{The percentile of the null permutation distribution of importance used as a threshold for variable selection. The default is \code{pctl = .95}.}

\item{scale}{Should the permutation importances be ``scaled''? The default value is \code{FALSE}.}

\item{sidak}{Should a Sidak correction for multiple tests be made based on the number of predictors? The default is \code{TRUE}.}

\item{iterate}{Should variable selection using traditional RF importance run iteratively until no new variables are dropped? The default is \code{FALSE}.}

\item{permcores}{Number of processor cores to use for parallel computing with package \pkg{parallel} for running the \code{perms} permutations. The default is no parallel computing (i.e., \code{permcores = 1}). Note that pkg{parallel} is not compatible with Windows versions of R. Specifically, if running Windows, \code{mclapply} will revert to \code{lapply}, so the function will still run, but with no parallelization.}
}
\description{
This function implements causal variable selection by combining de Luna, Waernbaum, & Richardson's (2011) "XY" algorithm with permutation-based tests of conditional independence based on conditional random forest permutation imporance. The data are preprocessed to screen out noise variables using traditional random forest permutation importance, which is much less computationally expensive. Then, a final pass is made using conditional variable importance.
}
\keyword{Conditional}
\keyword{Forest}
\keyword{Importance}
\keyword{Permutation}
\keyword{Random}
\keyword{Selection}
\keyword{Variable}
